import { sentryUnpluginFactory, getDebugIdSnippet } from '@sentry/bundler-plugin-core';
export { sentryCliBinaryExists } from '@sentry/bundler-plugin-core';
import * as path from 'path';
import { v4 } from 'uuid';
import { BannerPlugin } from 'webpack-4';

function webpackReleaseInjectionPlugin(injectionCode) {
  return {
    name: "sentry-webpack-release-injection-plugin",
    webpack: function webpack(compiler) {
      var _compiler$webpack;
      if (compiler !== null && compiler !== void 0 && (_compiler$webpack = compiler.webpack) !== null && _compiler$webpack !== void 0 && _compiler$webpack.BannerPlugin) {
        compiler.options.plugins.push(new compiler.webpack.BannerPlugin({
          raw: true,
          include: /\.(js|ts|jsx|tsx|mjs|cjs)$/,
          banner: injectionCode
        }));
      } else {
        compiler.options.plugins.push(
        // eslint-disable-next-line @typescript-eslint/no-unsafe-argument, @typescript-eslint/no-unsafe-call
        new BannerPlugin({
          raw: true,
          include: /\.(js|ts|jsx|tsx|mjs|cjs)$/,
          banner: injectionCode
        }));
      }
    }
  };
}
function webpackDebugIdInjectionPlugin() {
  return {
    name: "sentry-webpack-debug-id-injection-plugin",
    webpack: function webpack(compiler) {
      var _compiler$webpack2;
      if (compiler !== null && compiler !== void 0 && (_compiler$webpack2 = compiler.webpack) !== null && _compiler$webpack2 !== void 0 && _compiler$webpack2.BannerPlugin) {
        compiler.options.plugins.push(new compiler.webpack.BannerPlugin({
          raw: true,
          include: /\.(js|ts|jsx|tsx|mjs|cjs)$/,
          banner: function banner() {
            return getDebugIdSnippet(v4());
          }
        }));
      } else {
        compiler.options.plugins.push(
        // eslint-disable-next-line @typescript-eslint/no-unsafe-argument, @typescript-eslint/no-unsafe-call
        new BannerPlugin({
          raw: true,
          include: /\.(js|ts|jsx|tsx|mjs|cjs)$/,
          banner: function banner() {
            return getDebugIdSnippet(v4());
          }
        }));
      }
    }
  };
}
function webpackDebugIdUploadPlugin(upload) {
  var pluginName = "sentry-webpack-debug-id-upload-plugin";
  return {
    name: pluginName,
    webpack: function webpack(compiler) {
      compiler.hooks.afterEmit.tapAsync(pluginName, function (compilation, callback) {
        var _compilation$outputOp;
        var outputPath = (_compilation$outputOp = compilation.outputOptions.path) !== null && _compilation$outputOp !== void 0 ? _compilation$outputOp : path.resolve();
        var buildArtifacts = Object.keys(compilation.assets).map(function (asset) {
          return path.join(outputPath, asset);
        });
        void upload(buildArtifacts).then(function () {
          callback();
        });
      });
    }
  };
}
var sentryUnplugin = sentryUnpluginFactory({
  releaseInjectionPlugin: webpackReleaseInjectionPlugin,
  debugIdInjectionPlugin: webpackDebugIdInjectionPlugin,
  debugIdUploadPlugin: webpackDebugIdUploadPlugin
});

// eslint-disable-next-line @typescript-eslint/no-explicit-any
var sentryWebpackPlugin = sentryUnplugin.webpack;

export { sentryWebpackPlugin };
//# sourceMappingURL=index.mjs.map
